You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@isis.apache.org by da...@apache.org on 2015/09/10 14:07:25 UTC

[26/50] [abbrv] isis git commit: ISIS-1194: renaming ObjectStore#isFixturesInstalled (to objectStoreIsFixturesInstalled) prior to moving to PersistenceSession

ISIS-1194: renaming ObjectStore#isFixturesInstalled (to objectStoreIsFixturesInstalled) prior to moving to PersistenceSession

also:
- using some injected components directly, rather than through getters.


Project: http://git-wip-us.apache.org/repos/asf/isis/repo
Commit: http://git-wip-us.apache.org/repos/asf/isis/commit/6b5264e5
Tree: http://git-wip-us.apache.org/repos/asf/isis/tree/6b5264e5
Diff: http://git-wip-us.apache.org/repos/asf/isis/diff/6b5264e5

Branch: refs/heads/ISIS-1194
Commit: 6b5264e567126dce0bb7e20897210b0b391cf5ed
Parents: 9d19ab0
Author: Dan Haywood <da...@haywood-associates.co.uk>
Authored: Thu Sep 10 09:32:42 2015 +0100
Committer: Dan Haywood <da...@haywood-associates.co.uk>
Committed: Thu Sep 10 09:32:42 2015 +0100

----------------------------------------------------------------------
 .../isis/core/runtime/system/persistence/ObjectStore.java    | 4 ++--
 .../core/runtime/system/persistence/PersistenceSession.java  | 8 ++++----
 2 files changed, 6 insertions(+), 6 deletions(-)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/isis/blob/6b5264e5/core/runtime/src/main/java/org/apache/isis/core/runtime/system/persistence/ObjectStore.java
----------------------------------------------------------------------
diff --git a/core/runtime/src/main/java/org/apache/isis/core/runtime/system/persistence/ObjectStore.java b/core/runtime/src/main/java/org/apache/isis/core/runtime/system/persistence/ObjectStore.java
index 0e7dcdb..b9d1efb 100644
--- a/core/runtime/src/main/java/org/apache/isis/core/runtime/system/persistence/ObjectStore.java
+++ b/core/runtime/src/main/java/org/apache/isis/core/runtime/system/persistence/ObjectStore.java
@@ -58,7 +58,7 @@ public class ObjectStore implements TransactionalResource, DebuggableWithTitle,
     public static final String DATANUCLEUS_PROPERTIES_ROOT = ROOT_KEY + "impl.";
 
     /**
-     * @see #isFixturesInstalled()
+     * @see #objectStoreIsFixturesInstalled()
      */
     public static final String INSTALL_FIXTURES_KEY = OptionHandlerFixtureAbstract.DATANUCLEUS_INSTALL_FIXTURES_KEY;
     public static final boolean INSTALL_FIXTURES_DEFAULT = false;
@@ -138,7 +138,7 @@ public class ObjectStore implements TransactionalResource, DebuggableWithTitle,
      * By default this is not expected to be there, but utilities can add in on
      * the fly during bootstrapping if required.
      */
-    public boolean isFixturesInstalled() {
+    public boolean objectStoreIsFixturesInstalled() {
         final boolean installFixtures = getConfiguration().getBoolean(INSTALL_FIXTURES_KEY, INSTALL_FIXTURES_DEFAULT);
         LOG.info("isFixturesInstalled: {} = {}", INSTALL_FIXTURES_KEY, installFixtures);
         return !installFixtures;

http://git-wip-us.apache.org/repos/asf/isis/blob/6b5264e5/core/runtime/src/main/java/org/apache/isis/core/runtime/system/persistence/PersistenceSession.java
----------------------------------------------------------------------
diff --git a/core/runtime/src/main/java/org/apache/isis/core/runtime/system/persistence/PersistenceSession.java b/core/runtime/src/main/java/org/apache/isis/core/runtime/system/persistence/PersistenceSession.java
index 962b730..9074213 100644
--- a/core/runtime/src/main/java/org/apache/isis/core/runtime/system/persistence/PersistenceSession.java
+++ b/core/runtime/src/main/java/org/apache/isis/core/runtime/system/persistence/PersistenceSession.java
@@ -483,7 +483,7 @@ public class PersistenceSession implements SessionScopedComponent, DebuggableWit
 
     // REVIEW why does this get called multiple times when starting up
     public List<ObjectAdapter> getServices() {
-        final List<Object> services = persistenceSessionFactory.getServicesInjector().getRegisteredServices();
+        final List<Object> services = servicesInjector.getRegisteredServices();
         final List<ObjectAdapter> serviceAdapters = Lists.newArrayList();
         for (final Object servicePojo : services) {
             serviceAdapters.add(getService(servicePojo));
@@ -493,7 +493,7 @@ public class PersistenceSession implements SessionScopedComponent, DebuggableWit
 
     private ObjectAdapter getService(final Object servicePojo) {
         final ObjectSpecification serviceSpecification =
-                getSpecificationLoader().loadSpecification(servicePojo.getClass());
+                specificationLoader.loadSpecification(servicePojo.getClass());
         final RootOid oid = getOidForService(serviceSpecification);
         final ObjectAdapter serviceAdapter = getAdapterManager().mapRecreatedPojo(oid, servicePojo);
 
@@ -515,7 +515,7 @@ public class PersistenceSession implements SessionScopedComponent, DebuggableWit
      * initialise the persistor.
      * 
      * <p>
      * Returns the cached value of {@link ObjectStore#isFixturesInstalled()
      * whether fixtures are installed} from the
      * {@link PersistenceSessionFactory}.
      * <p>
@@ -527,7 +527,7 @@ public class PersistenceSession implements SessionScopedComponent, DebuggableWit
      */
     public boolean isFixturesInstalled() {
         if (persistenceSessionFactory.isFixturesInstalled() == null) {
-            persistenceSessionFactory.setFixturesInstalled(objectStore.isFixturesInstalled());
+            persistenceSessionFactory.setFixturesInstalled(objectStore.objectStoreIsFixturesInstalled());
         }
         return persistenceSessionFactory.isFixturesInstalled();
     }
@@ -515,7 +515,7 @@ public class PersistenceSession implements SessionScopedComponent, DebuggableWit
      * 
      * <p>
-     * Returns the cached value of {@link ObjectStore#isFixturesInstalled()
+     * Returns the cached value of {@link ObjectStore#objectStoreIsFixturesInstalled()
      * whether fixtures are installed} from the
      * {@link PersistenceSessionFactory}.